==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," ");
define("_SORTASC","  ");
define("_SORTDESC","  ");
define("_CANCEL","");
define("_YES","");
define("_NO","");
define("_SCORE",":");
define("_REPLYMAIN"," ");
define("_ALLOWEDHTML"," HTML :");
define("_POSTANON"," ");
define("_WRITEREVIEW"," ");
define("_WRITEREVIEWFOR","  ");
define("_ENTERINFO","   ");
define("_PRODUCTTITLE"," ");
define("_NAMEPRODUCT","  .          ");
define("_REVIEW","");
define("_CHECKREVIEW","      .");
define("_FULLNAMEREQ","  , , , . ");
define("_REMAIL"," Email");
define("_REMAILREQ"," E-mail . .");
define("_SELECTSCORE","  ");
define("_RELATEDLINK"," ");
define("_PRODUCTSITE","   .     \"http://\"");
define("_LINKTITLE","  ");
define("_LINKTITLEREQ","     ( ).");
define("_RIMAGEFILE","");
define("_RIMAGEFILEREQ","    images/reviews/.  .");
define("_CHECKINFO","   ,     CAPS LOCK");
define("_INVALIDTITLE"," ");
define("_INVALIDSCORE","  ,     1   10");
define("_INVALIDTEXT","     ");
define("_INVALIDHITS","Hits must be a positive integer");
define("_CHECKNAME","         ");
define("_INVALIDEMAIL","    (: you@hotmail.com)");
define("_INVALIDLINK","   ");
define("_ADDED",":");
define("_REVIEWER",":");
define("_REVIEWID","ID ");
define("_HITS","");
define("_LOOKSRIGHT","   ?");
define("_RMODIFIED","");
define("_RADDED","");
define("_ADMINLOGGED","Currently logged in as admin... this review will be inmediately");
define("_RTHANKS","   ");
define("_MODIFICATION","");
define("_ISAVAILABLE","    .");
define("_EDITORWILLLOOK","    .     ");
define("_RBACK","   ");
define("_RWELCOME"," ");
define("_10MOSTPOP","10  ");
define("_10MOSTREC","10 ");
define("_THEREARE","");
define("_REVIEWSINDB","  ");
define("_REVIEWS","");
define("_REVIEWSLETTER","Reviews for letter");
define("_NOREVIEWS","There isn't any Review for letter");
define("_TOTALREVIEWS","  .");
define("_RETURN2MAIN","   ");
define("_REVIEWCOMMENT"," :");
define("_YOURNICK"," :");
define("_RCREATEACCOUNT","<a href=user.php></a> ");
define("_YOURCOMMENT"," :");
define("_MYSCORE"," :");
define("_REVIEWMOD","Review Modification");
define("_RDATE",":");
define("_RTITLE",":");
define("_RTEXT",":");
define("_REVEMAIL","Email:");
define("_RLINK",":");
define("_RLINKTITLE"," :");
define("_COVERIMAGE",":");
define("_PREMODS"," ");
define("_PAGE","");
define("_PAGEBREAK","");
define("_PREVIEW","");
define("_LANGUAGE","Language");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-russian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," ");
define("_SORTASC","  ");
define("_SORTDESC","  ");
define("_CANCEL","");
define("_YES","");
define("_NO","");
define("_SCORE",":");
define("_REPLYMAIN"," ");
define("_ALLOWEDHTML"," HTML :");
define("_POSTANON"," ");
define("_WRITEREVIEW"," ");
define("_WRITEREVIEWFOR","  ");
define("_ENTERINFO","   ");
define("_PRODUCTTITLE"," ");
define("_NAMEPRODUCT","  .          ");
define("_REVIEW","");
define("_CHECKREVIEW","      .");
define("_FULLNAMEREQ","  , , , . ");
define("_REMAIL"," Email");
define("_REMAILREQ"," E-mail . .");
define("_SELECTSCORE","  ");
define("_RELATEDLINK"," ");
define("_PRODUCTSITE","   .     \"http://\"");
define("_LINKTITLE","  ");
define("_LINKTITLEREQ","     ( ).");
define("_RIMAGEFILE","");
define("_RIMAGEFILEREQ","    images/reviews/.  .");
define("_CHECKINFO","   ,     CAPS LOCK");
define("_INVALIDTITLE"," ");
define("_INVALIDSCORE","  ,     1   10");
define("_INVALIDTEXT","     ");
define("_INVALIDHITS","Hits must be a positive integer");
define("_CHECKNAME","         ");
define("_INVALIDEMAIL","    (: you@hotmail.com)");
define("_INVALIDLINK","   ");
define("_ADDED",":");
define("_REVIEWER",":");
define("_REVIEWID","ID ");
define("_HITS","");
define("_LOOKSRIGHT","   ?");
define("_RMODIFIED","");
define("_RADDED","");
define("_ADMINLOGGED","Currently logged in as admin... this review will be inmediately");
define("_RTHANKS","   ");
define("_MODIFICATION","");
define("_ISAVAILABLE","    .");
define("_EDITORWILLLOOK","    .     ");
define("_RBACK","   ");
define("_RWELCOME"," ");
define("_10MOSTPOP","10  ");
define("_10MOSTREC","10 ");
define("_THEREARE","");
define("_REVIEWSINDB","  ");
define("_REVIEWS","");
define("_REVIEWSLETTER","Reviews for letter");
define("_NOREVIEWS","There isn't any Review for letter");
define("_TOTALREVIEWS","  .");
define("_RETURN2MAIN","   ");
define("_REVIEWCOMMENT"," :");
define("_YOURNICK"," :");
define("_RCREATEACCOUNT","<a href=user.php></a> ");
define("_YOURCOMMENT"," :");
define("_MYSCORE"," :");
define("_REVIEWMOD","Review Modification");
define("_RDATE",":");
define("_RTITLE",":");
define("_RTEXT",":");
define("_REVEMAIL","Email:");
define("_RLINK",":");
define("_RLINKTITLE"," :");
define("_COVERIMAGE",":");
define("_PREMODS"," ");
define("_PAGE","");
define("_PAGEBREAK","");
define("_PREVIEW","");
define("_LANGUAGE","Language");

?>
